function tsg_plot_SalTempVel( hTsgGUI, hAxes )
% Function to plot the Salinity, Temperature TSG data as well as the
% ship velocity
%
% Input
% -----
% hTsgGUI ............ Handel to the main user interface
% hPlotAxes .......... Handels to the 3 graphic axes
%
% Output
% ------
% $Id$

% Retrieve named application data
% -------------------------------
tsg = getappdata( hTsgGUI, 'tsg_data');
qc  = getappdata( hTsgGUI, 'qcColor');

% Plot the Salinity with the right color code
% -------------------------------------------
axes( hAxes(1));

ind = find(tsg.PSAL_QC <= qc.Code.NO_CONTROL );
plot(hAxes(1), tsg.TIME(ind), tsg.PSAL(ind), ...
               strcat('.',qc.Color.NO_CONTROL));

hold on;

ind = find(tsg.PSAL_QC == qc.Code.GOOD );
plot(hAxes(1), tsg.TIME(ind), tsg.PSAL(ind), ...
               strcat('.',qc.Color.GOOD));
           
ind = find(tsg.PSAL_QC == qc.Code.PROBABLY_GOOD );
plot(hAxes(1), tsg.TIME(ind), tsg.PSAL(ind), ...
               strcat('.',qc.Color.PROBABLY_GOOD));
           
ind = find(tsg.PSAL_QC == qc.Code.PROBABLY_BAD );
plot(hAxes(1), tsg.TIME(ind), tsg.PSAL(ind), ...
               strcat('.',qc.Color.PROBABLY_BAD));
           
ind = find(tsg.PSAL_QC == qc.Code.BAD );
plot(hAxes(1), tsg.TIME(ind), tsg.PSAL(ind), ...
               strcat('.',qc.Color.BAD));

% Plot Temperature and ship velocity with no qc color code
% ---------------------------------------------------------
plot(hAxes(2), tsg.TIME, tsg.TEMP_TSG, '.');
plot(hAxes(3), tsg.TIME, tsg.TEMP_TSG, '.');

% Formatted x-TIME axes
% ---------------------
datetick(hAxes(1), 'x');
datetick(hAxes(2), 'x');
datetick(hAxes(3), 'x');

% Write some 'Y' label
% ------------------
set(get(hAxes(1), 'Ylabel'), 'String', 'Salinity');
set(get(hAxes(2), 'Ylabel'), 'String', 'Temperature (C)');
set(get(hAxes(3), 'Ylabel'), 'String', 'Ship Velocity');

% Make the axes visible
% ---------------------
set(hAxes(1), 'Visible', 'on' );
set(hAxes(2), 'Visible', 'on' );
set(hAxes(3), 'Visible', 'on' );

% The 3 axes will behave identically when zoomed and panned
% ---------------------------------------------------------
linkaxes([hAxes(1),hAxes(2),hAxes(3)], 'x');

end
